@@ -1,5 +1,5 @@
 package Net::Fortinet::FortiManager;
-$Net::Fortinet::FortiManager::VERSION = '0.003000';
+$Net::Fortinet::FortiManager::VERSION = '0.003001';
 # ABSTRACT: Fortinet FortiManager REST API client library
 
 use 5.024;
@@ -512,7 +512,7 @@ sub delete_policy_package ($self, $name) {
 }
 
 
-sub install_policy_package ($self, $name, $data) {
+sub install_policy_package ($self, $name, $data = {}) {
     my $params = {
         data => {
             $data->%*,
@@ -520,8 +520,10 @@ sub install_policy_package ($self, $name, $data) {
             pkg     => $name,
         },
     };
-    $self->exec_method('exec', '/securityconsole/install/package',
+    my $res = $self->exec_method('exec', '/securityconsole/install/package',
         $params);
+
+    return $res->{task};
 }
 
 
@@ -535,6 +537,23 @@ sub get_task ($self, $id, $params = {}) {
 }
 
 
+sub wait_for_task($self, $taskid, $callback = undef) {
+    croak "task-id missing"
+        unless defined $taskid;
+    croak "callback must be a coderef"
+        if defined $callback && ref $callback ne 'CODE';
+
+    my $task;
+    while (($task = $self->get_task($taskid))
+        && $task->{percent} != 100) {
+        &$callback($task)
+            if defined $callback;
+        sleep 1;
+    }
+    return $task;
+}
+
+
 sub list_firewall_policies ($self, $pkg, $params = {}) {
     $self->exec_method('get', '/pm/config/adom/' . $self->adom .
         '/pkg/' .  $pkg . '/firewall/policy', $params);
@@ -630,7 +649,7 @@ Net::Fortinet::FortiManager - Fortinet FortiManager REST API client library
 
 =head1 VERSION
 
-version 0.003000
+version 0.003001
 
 =head1 SYNOPSIS
 
@@ -969,7 +988,7 @@ Throws an exception on error.
 
 Takes a policy package name and a hashref of parameters.
 
-Returns true on success.
+Returns the task id on success.
 
 Throws an exception on error.
 
@@ -985,6 +1004,13 @@ Takes a task id and an optional parameter hashref.
 
 Returns its data as a hashref.
 
+=head2 wait_for_task
+
+Takes a task id and checks its status every second until its percent
+have reached 100 and return the status.
+Takes an optional callback coderef which is called for every check with the
+task as argument.
+
 =head2 list_firewall_policies
 
 Takes a package name and optional parameters.
